@@ -1,3 +1,7 @@
+__all__ = [
+    'depth_first_apply',
+    'flatten_dict',
+]
 
 
 def depth_first_apply(dict_like, func):
@@ -14,4 +18,4 @@ def flatten_dict(dd, separator='/', prefix=''):
     return {prefix + separator + k if prefix else k: v
             for kk, vv in dd.items()
             for k, v in flatten_dict(vv, separator, kk).items()
-            } if isinstance(dd, dict) else {prefix: dd}
\ No newline at end of file
+            } if isinstance(dd, dict) else {prefix: dd}
